#!/usr/bin/perl -w

use ExtUtils::testlib;
use Data::Dumper;

use Getopt::Long;

BEGIN { $t = 0; print "1..10\n"; }

my $endpoint = $ENV{CHANNEL_ENDPOINT};
my $verbose = 0;

GetOptions("endpoint=s" => \$endpoint, "verbose!" => \$verbose);

use GLite::Data::ChannelManagement;

die "Please set the endpoint!\n" unless defined $endpoint;

my $channel = GLite::Data::ChannelManagement->new($endpoint);

# check the server's version number
print "Server version\n";
eval { print "ChannelManagement service version is: ", $channel->getVersion(), "\n"; };
$t++; if ($@) { print $@; print "not "; } print "ok $t\n";

my $channelName = 'private-pipe';

eval { 
    $channels=$channel->listChannels();
    print "listChannels: ", join("\n", @$channels), "\n"; 
};
$t++; if ($@) { print $@; print "not "; } print "ok $t\n";

# drop, if already exists
if (grep(/$channelName/, @$channels)) {
    $channel->drop($channelName);
}

eval { 
   print "add: \n";
   $channel->add({
        channelName => $channelName,
        bandwith => 100,
        contact => '',
        domainA => 'cern.ch',
        domainB => 'fnal.gov',
        nominalThroughput => 100,
        numberOfFiles => 5,
        state => 'Active'
    });
};
$t++; if ($@) { print $@; print "not "; } print "ok $t\n";


eval { 
   print "add again: \n";
   $channel->add({
        channelName => $channelName,
        bandwith => 100,
        contact => '',
        domainA => 'cern.ch',
        domainB => 'fnal.gov',
        nominalThroughput => 100,
        numberOfFiles => 5,
        state => 'Active'
    });
};
$t++; if (!$@) { print "not "; } print "ok $t\n";


eval { 
    print "getChannel: ", Dumper($channel->getChannel($channelName)), "\n"; 
};
$t++; if ($@) { print $@; print "not "; } print "ok $t\n";


eval { 
  print "setConcact: \n";
   $channel->setContact($channelName, 'user@example.org');
};
$t++; if ($@) { print $@; print "not "; } print "ok $t\n";

eval { 
    print "getChannel: ", Dumper($channel->getChannel($channelName)), "\n"; 
};
$t++; if ($@) { print $@; print "not "; } print "ok $t\n";

eval { 
  print "setState: \n";
   $channel->setState($channelName, 'Drain');
};
$t++; if ($@) { print $@; print "not "; } print "ok $t\n";

eval { 
    print "getChannel: ", Dumper($channel->getChannel($channelName)), "\n"; 
};
$t++; if ($@) { print $@; print "not "; } print "ok $t\n";

eval { 
  print "drop: \n";
   $channel->drop($channelName);
};
$t++; if ($@) { print $@; print "not "; } print "ok $t\n";

