#!/usr/bin/perl -w

use ExtUtils::testlib;
use Data::Dumper;

use Getopt::Long;

BEGIN { $t=0; print "1..10\n"; }

my $endpoint = $ENV{TRANSFER_ENDPOINT};
my $verbose = 0;

GetOptions("endpoint=s" => \$endpoint, "verbose!" => \$verbose);

use GLite::Data::FileTransfer;

die "Please set the endpoint!\n" unless defined $endpoint;

$src_file = 'srm://castorsrm.cern.ch:8443/castor/cern.ch/tmp/perl-source-file';

$dest_file = 'srm://castorsrm.cern.ch:8443/castor/cern.ch/tmp/perl-destination-file';

my $transfer = GLite::Data::FileTransfer->new($endpoint);

# check the server's version number
print "Server version\n";
eval { print "Transfer service version is: ", $transfer->getVersion(), "\n"; };
$t++; if ($@) { print $@; print "not "; } print "ok $t\n";

my $emptyparams = { 'keys' => [ "" ], 'values' => [ "" ] };

# submit one file transfer request
my $requestid = undef;
eval {
    print "submit: \n";
    my $job = {
        jobParams => $emptyparams,
        'credential' => 'changeit',
        transferJobElements => [
            { transferParams => $emptyparams, source => $src_file, dest => $dest_file }
        ]
    };
    $requestid = $transfer->submit($job);
    print "Got requestID from service: $requestid\n";
};
$t++; if ($@) { print $@; print "not "; } print "ok $t\n";

eval { print "status for $requestid: ", Dumper($transfer->getTransferJobStatus($requestid)), "\n"; };
$t++; if ($@) { print $@; print "not "; } print "ok $t\n";

eval { print "summary for $requestid: ", Dumper($transfer->getTransferJobSummary($requestid)), "\n"; };
$t++; if ($@) { print $@; print "not "; } print "ok $t\n";

eval { print "file status for $requestid: ", Dumper($transfer->getFileStatus($requestid, 0, 100)), "\n"; };
$t++; if ($@) { print $@; print "not "; } print "ok $t\n";

eval { 
    print "canceling $requestid: \n";
    $transfer->cancel([$requestid]);
};
$t++; if ($@) { print $@; print "not "; } print "ok $t\n";

# complex job

eval {
    print "submit: \n";
    my $job = {
        jobParams => $emptyparams,
        'credential' => 'changeit',
        transferJobElements => [ ]
    };
    for my $i (0 .. 2) {
        push(@{$job->{'transferJobElements'}}, 
            { transferParams => $emptyparams, source => $src_file . $i, dest => $dest_file . $i}
        );
    }
    $requestid = $transfer->submit($job);
    print "Got requestID from service: $requestid\n";
};
$t++; if ($@) { print $@; print "not "; } print "ok $t\n";

eval { print "status for $requestid: ", Dumper($transfer->getTransferJobStatus($requestid)), "\n"; };
$t++; if ($@) { print $@; print "not "; } print "ok $t\n";

# multi-job manipulations

eval { 
    $jobs = $transfer->listRequests(["Submitted"], undef);
    print "list of Submitted requests: ", Dumper($jobs), "\n"; };
    $jobids = [ map { $_->{'jobID'} } @$jobs ];
$t++; if ($@) { print $@; print "not "; } print "ok $t\n";

eval {
    print "canceling the 'Submitted' jobs: \n", join("\n", @$jobids), "\n";
    $transfer->cancel($jobids);
};
$t++; if ($@) { print $@; print "not "; } print "ok $t\n";

