#!/usr/bin/perl -w

use ExtUtils::testlib;
use Data::Dumper;

use Getopt::Long;

BEGIN { print "1..3\n"; }

my $endpoint = $ENV{TRANSFER_ENDPOINT};
my $verbose = 0;

GetOptions("endpoint=s" => \$endpoint, "verbose!" => \$verbose);

use GLite::Data::FileTransfer;

die "Please set the endpoint!\n" unless defined $endpoint;

my $src_file = shift(@ARGV);
$src_file = 'srm:/tmp/perl-source-file' unless defined $src_file;

my $dest_file = shift(@ARGV);
$dest_file = 'srm:/tmp/perl-destination-file' unless defined $dest_file;

print "Contacting $endpoint...\n";
print "Source file: $src_file\n";
print "Destination file: $dest_file\n";

my $transfer = GLite::Data::FileTransfer->new($endpoint);

# check the server's version number
print "Server version\n";
eval { print "Transfer service version is: ", $transfer->getVersion(), "\n"; };
if ($@) { print $@; print "not "; } print "ok 1\n";

my $emptyparams = { 'keys' => [ "" ], 'values' => [ "" ] };

# submit one file transfer request
my $requestid = undef;
eval {
    my $job = {
        jobParams => $emptyparams,
        'credential' => 'changeit',
        transferJobElements => [
            { transferParams => $emptyparams, source => $src_file, dest => $dest_file }
        ]
    };
    $requestid = $transfer->submit($job);
    print "Got requestID from service: $requestid\n";
};
if ($@) { print $@; print "not "; } print "ok 2\n";

# wait for 'done' status
eval {
    my $status = $transfer->getTransferJobStatus($requestid);
    while ($status->{'jobStatus'} !~ /Done|Failed/i) {
        print "Got status <", $status->{'jobStatus'}, "> for requestID: $requestid\n";
        sleep 1;
        $status = $transfer->getTransferJobStatus($requestid);
    }
    print "Final status was: $status\n"
};
if ($@) { print $@; print "not "; } print "ok 3\n";

